@@ -370,16 +370,19 @@ void do_disk(void)
     char *disk,*bios,*sectors,*heads,*cylinders,*maxpart;
     int major;
 
+    disk = cfg_get_strg(cf_options,"disk");
     cfg_init(cf_disk);
     (void) cfg_parse(cf_disk);
-    disk = cfg_get_strg(cf_options,"disk");
-    
-    if (!cfg_get_flag(cf_disk,"inaccessible")) {
-      if (stat(disk,&st) < 0) die("stat %s: %s",disk,strerror(errno));
-      if (!S_ISBLK(st.st_mode) || 
-               (has_partitions(st.st_rdev) && (MINOR(st.st_rdev) & P_MASK(st.st_rdev))))
-                       die(" '%s' is not a whole disk device",disk);
+    if (stat(disk,&st) < 0) {
+        if (cfg_get_flag(cf_disk,"inaccessible")) {
+            cfg_unset(cf_options,"disk");
+            return;
+        }
+        die("do_disk: stat %s: %s",disk,strerror(errno));
     }
+    if (!S_ISBLK(st.st_mode) || 
+    	(has_partitions(st.st_rdev) && (MINOR(st.st_rdev) & P_MASK(st.st_rdev))))
+		die(" '%s' is not a whole disk device",disk);
 
     entry = alloc_t(DT_ENTRY);
     entry->device = st.st_rdev;
@@ -1116,9 +1119,19 @@ void geo_get(GEOMETRY *geo,int device,int user_device,int all)
 	
 	if (ioctl(md_fd,GET_ARRAY_INFO,&md_array_info) < 0)
 	    die("Unable to get RAID info on %s", mdxxx);
-	if ((md_array_info.major_version != md_version_info.major) &&
-		(md_array_info.minor_version != md_version_info.minor))
-	    die("Inconsistent Raid version information on %s", mdxxx);
+        if (md_version_info.major != 0 || md_version_info.minor != 90 ||
+            ((md_array_info.major_version != 0 ||
+                md_array_info.minor_version != 90) &&
+             (md_array_info.major_version != 1 ||
+                md_array_info.minor_version != 0))
+            ) {
+            die("Incompatible Raid version information on %s   (RV=%d.%d GAI=%d.%d)",
+                mdxxx,
+                (int)md_version_info.major,
+                (int)md_version_info.minor,
+                (int)md_array_info.major_version,
+                (int)md_array_info.minor_version);
+            }
 	if (md_array_info.level != 1)
 	    die("Only RAID1 devices are supported for boot images");
 	raid_limit = md_array_info.raid_disks + md_array_info.spare_disks;
